@@ -3,32 +3,61 @@
 #
 # Copyright (c) 2022 Ingram Micro. All Rights Reserved.
 #
-import os
 import logging
+import os
 import subprocess
-from datetime import datetime
-from importlib.metadata import entry_points, version
-from uuid import uuid4
+from datetime import (
+    datetime,
+)
+from importlib.metadata import (
+    entry_points,
+    version,
+)
+from uuid import (
+    uuid4,
+)
 
 import requests
-from rich import box
-from rich.align import Align
-from rich.markdown import Markdown
-from rich.table import Table
-from rich.syntax import Syntax
+from connect.client import (
+    ClientError,
+    ConnectClient,
+)
+from rich import (
+    box,
+)
+from rich.align import (
+    Align,
+)
+from rich.markdown import (
+    Markdown,
+)
+from rich.syntax import (
+    Syntax,
+)
+from rich.table import (
+    Table,
+)
 
-from connect.client import ClientError, ConnectClient
-from connect.eaas.core.validation.models import ValidationItem, ValidationResult
-from connect.eaas.core.validation.validators import get_validators
+from connect.eaas.core.validation.models import (
+    ValidationItem,
+    ValidationResult,
+)
+from connect.eaas.core.validation.validators import (
+    get_validators,
+)
 from connect.eaas.runner.constants import (
     BACKGROUND_TASK_MAX_EXECUTION_TIME,
     HANDLER_CLASS_TITLE,
     INTERACTIVE_TASK_MAX_EXECUTION_TIME,
     ORDINAL_SUFFIX,
     PYPI_EXTENSION_RUNNER_URL,
+    ROW_TRANSFORMATION_TASK_MAX_EXECUTION_TIME,
     SCHEDULED_TASK_MAX_EXECUTION_TIME,
+    TRANSFORMATION_TASK_MAX_EXECUTION_TIME,
+    TRANSFORMATION_WRITE_QUEUE_TIMEOUT,
 )
 
+
 logger = logging.getLogger('connect.eaas')
 
 
@@ -84,6 +113,18 @@ def get_environment():
         'scheduled_task_max_execution_time': int(os.getenv(
             'SCHEDULED_TASK_MAX_EXECUTION_TIME', SCHEDULED_TASK_MAX_EXECUTION_TIME,
         )),
+        'transformation_task_max_execution_time': int(os.getenv(
+            'TRANSFORMATION_TASK_MAX_EXECUTION_TIME', TRANSFORMATION_TASK_MAX_EXECUTION_TIME,
+        )),
+        'row_transformation_task_max_execution_time': int(
+            os.getenv(
+                'ROW_TRANSFORMATION_TASK_MAX_EXECUTION_TIME',
+                ROW_TRANSFORMATION_TASK_MAX_EXECUTION_TIME,
+            ),
+        ),
+        'transformation_write_queue_timeout': int(os.getenv(
+            'TRANSFORMATION_WRITE_QUEUE_TIMEOUT', TRANSFORMATION_WRITE_QUEUE_TIMEOUT,
+        )),
     }
 
 
@@ -114,7 +155,7 @@ def get_connect_version():
     return connect_client.response.headers['Connect-Version']
 
 
-def get_pypi_runner_minor_version(major_version):
+def get_pypi_runner_latest_version(major_version):
     res = requests.get(PYPI_EXTENSION_RUNNER_URL)
     if res.status_code != 200:
         logger.error(
@@ -128,8 +169,8 @@ def get_pypi_runner_minor_version(major_version):
         for version in content['releases'] if version.startswith(f'{major_version}.')
     ]
     if tags:
-        return str(max(tags))
-    return content['info']['version'].split('.')[1]
+        return f'{major_version}.{str(max(tags))}'
+    return content['info']['version']
 
 
 def get_client():
@@ -238,19 +279,16 @@ def check_runner_version(context):
         connect_full_version = get_connect_version()
         connect_version = connect_full_version.split('.')[0]
         runner_version = get_version()
-        latest_minor_version = get_pypi_runner_minor_version(connect_version)
+        latest_runner_version = get_pypi_runner_latest_version(connect_version)
 
-        if not (
-                connect_version == runner_version.split('.')[0]
-                and runner_version.split('.')[1] == latest_minor_version
-        ):
+        if runner_version != latest_runner_version:
             return ValidationResult(
                 items=[
                     ValidationItem(
                         level='ERROR',
                         message=(
                             'Runner is outdated, please, update. '
-                            f'Required version {connect_version}.{latest_minor_version}, '
+                            f'Required version {latest_runner_version}, '
                             f'current version: {runner_version}.'
                         ),
                     ),
@@ -502,6 +540,38 @@ def get_webapp_detail_table(details):
     return grid
 
 
+def get_tfnapp_detail_table(details):
+    grid = Table.grid(expand=True)
+    grid.add_column()
+
+    transformations = details['features'].get('transformations')
+
+    if transformations:
+        table = Table(
+            box=box.MINIMAL_HEAVY_HEAD,
+            title='Transformations',
+            title_style='blue',
+            show_header=True,
+            expand=True,
+            row_styles=['', 'dim'],
+        )
+        table.add_column('Name')
+        table.add_column('Description')
+        table.add_column('Edit dialog')
+        table.add_column('Method')
+        for transformation in transformations:
+            table.add_row(
+                transformation['name'],
+                transformation['description'],
+                transformation['edit_dialog_ui'],
+                transformation['method'],
+            )
+
+        grid.add_row(table)
+
+    return grid
+
+
 def get_features_table(features):
     table = Table(
         box=box.ROUNDED,
@@ -541,4 +611,10 @@ def get_features_table(features):
                 Align.center('[green]\u2714[/]'),
                 Align.center(get_anvilapp_detail_table(details)),
             )
+        elif feature_handler == 'TfnApp':
+            table.add_row(
+                HANDLER_CLASS_TITLE[feature_handler],
+                Align.center('[green]\u2714[/]'),
+                Align.center(get_tfnapp_detail_table(details)),
+            )
     return table
