@@ -7,25 +7,32 @@ import asyncio
 import logging
 import signal
 
-from devtools import pformat
+from devtools import (
+    pformat,
+)
 
 from connect.eaas.core.proto import (
     Message,
     MessageType,
     SetupRequest,
 )
-from connect.eaas.runner.workers.base import WorkerBase
 from connect.eaas.runner.constants import (
     DELAY_ON_CONNECT_EXCEPTION_SECONDS,
     RESULT_SENDER_MAX_RETRIES,
     RESULT_SENDER_WAIT_GRACE_SECONDS,
 )
-from connect.eaas.runner.helpers import configure_logger, get_version
+from connect.eaas.runner.helpers import (
+    configure_logger,
+    get_version,
+)
 from connect.eaas.runner.managers import (
     BackgroundTasksManager,
     InteractiveTasksManager,
     ScheduledTasksManager,
 )
+from connect.eaas.runner.workers.base import (
+    WorkerBase,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -38,8 +45,8 @@ class EventsWorker(WorkerBase):
     the server and wait for tasks that need to be processed using
     the tasks manager.
     """
-    def __init__(self, handler, runner_type=None):
-        super().__init__(handler)
+    def __init__(self, handler, lock, startup_fired, shutdown_fired, runner_type=None):
+        super().__init__(handler, lock, startup_fired, shutdown_fired)
         self.runner_type = runner_type
         self.results_queue = asyncio.Queue()
         self.background_manager = BackgroundTasksManager(
@@ -106,7 +113,7 @@ class EventsWorker(WorkerBase):
         message = Message.deserialize(data)
         logger.debug(f'Received message: {pformat(message)}')
         if message.message_type == MessageType.SETUP_RESPONSE:
-            self.process_setup_response(message.data)
+            await self.process_setup_response(message.data)
         elif message.message_type == MessageType.TASK:
             await self.process_task(message.data)
         elif message.message_type == MessageType.SHUTDOWN:
@@ -202,9 +209,25 @@ class EventsWorker(WorkerBase):
         return super().__repr__()
 
 
-def _start_event_worker_process(handler, runner_type, debug, no_rich):
+def _start_event_worker_process(
+    handler_class,
+    config,
+    lifecycle_lock,
+    on_startup_fired,
+    on_shutdown_fired,
+    runner_type,
+    debug,
+    no_rich,
+):
+    handler = handler_class(config)
     configure_logger(debug, no_rich)
-    worker = EventsWorker(handler, runner_type=runner_type)
+    worker = EventsWorker(
+        handler,
+        lifecycle_lock,
+        on_startup_fired,
+        on_shutdown_fired,
+        runner_type=runner_type,
+    )
     loop = asyncio.get_event_loop()
     loop.add_signal_handler(
         signal.SIGINT,
@@ -217,9 +240,43 @@ def _start_event_worker_process(handler, runner_type, debug, no_rich):
     loop.run_until_complete(worker.start())
 
 
-def start_interactive_worker_process(handler, debug, no_rich):
-    _start_event_worker_process(handler, 'interactive', debug, no_rich)
+def start_interactive_worker_process(
+    handler_class,
+    config,
+    lifecycle_lock,
+    on_startup_fired,
+    on_shutdown_fired,
+    debug,
+    no_rich,
+):
+    _start_event_worker_process(
+        handler_class,
+        config,
+        lifecycle_lock,
+        on_startup_fired,
+        on_shutdown_fired,
+        'interactive',
+        debug,
+        no_rich,
+    )
 
 
-def start_background_worker_process(handler, debug, no_rich):
-    _start_event_worker_process(handler, 'background', debug, no_rich)
+def start_background_worker_process(
+    handler_class,
+    config,
+    lifecycle_lock,
+    on_startup_fired,
+    on_shutdown_fired,
+    debug,
+    no_rich,
+):
+    _start_event_worker_process(
+        handler_class,
+        config,
+        lifecycle_lock,
+        on_startup_fired,
+        on_shutdown_fired,
+        'background',
+        debug,
+        no_rich,
+    )
