@@ -11,7 +11,9 @@ import logging
 import signal
 
 import httpx
-from devtools import pformat
+from devtools import (
+    pformat,
+)
 
 from connect.eaas.core.proto import (
     HttpRequest,
@@ -21,8 +23,13 @@ from connect.eaas.core.proto import (
     SetupRequest,
     WebTask,
 )
-from connect.eaas.runner.workers.base import WorkerBase
-from connect.eaas.runner.helpers import configure_logger, get_version
+from connect.eaas.runner.helpers import (
+    configure_logger,
+    get_version,
+)
+from connect.eaas.runner.workers.base import (
+    WorkerBase,
+)
 
 
 logger = logging.getLogger(__name__)
@@ -65,7 +72,7 @@ class WebWorker(WorkerBase):
         message = Message.deserialize(data)
         logger.debug(f'Received message: {pformat(message)}')
         if message.message_type == MessageType.SETUP_RESPONSE:
-            self.process_setup_response(message.data)
+            await self.process_setup_response(message.data)
         elif message.message_type == MessageType.WEB_TASK:
             asyncio.create_task(self.process_task(message.data))
         elif message.message_type == MessageType.SHUTDOWN:
@@ -115,6 +122,8 @@ class WebWorker(WorkerBase):
         headers['X-Connect-Api-Gateway-Url'] = self.config.get_api_url()
         headers['X-Connect-User-Agent'] = self.config.get_user_agent()['User-Agent']
         headers['X-Connect-Extension-Id'] = self.config.service_id
+        headers['X-Connect-Environment-Id'] = self.config.environment_id
+        headers['X-Connect-Environment-Type'] = self.config.environment_type
         headers['X-Connect-Logging-Level'] = self.get_logging_level()
         headers['X-Connect-Config'] = json.dumps(self.config.variables)
 
@@ -175,9 +184,23 @@ class WebWorker(WorkerBase):
         return message.serialize()
 
 
-def start_webapp_worker_process(handler, debug, no_rich):
+def start_webapp_worker_process(
+    handler_class,
+    config,
+    lifecycle_lock,
+    on_startup_fired,
+    on_shutdown_fired,
+    debug,
+    no_rich,
+):
+    handler = handler_class(config)
     configure_logger(debug, no_rich)
-    worker = WebWorker(handler)
+    worker = WebWorker(
+        handler,
+        lifecycle_lock,
+        on_startup_fired,
+        on_shutdown_fired,
+    )
     loop = asyncio.get_event_loop()
     loop.add_signal_handler(
         signal.SIGINT,
